//=====================================================
//    File: CompoundSort.java
//    Show how to do a "compound sort" -- 
//    a sort on both a primary and secondary field
//=====================================================

import java.util.Arrays;

public class CompoundSort {

    private Name[] names = { new Name("Bary",     "Pollack"),
                             new Name("George",   "Bush"),
                             new Name("Barack",   "Obama"),
                             new Name("Jeb",      "Bush"),
                             new Name("Hillary",  "Clinton"),
                             new Name("John",     "McCain"),
                             new Name("Kimberly", "Pollack"),
                             new Name("George W", "Bush"),
                             new Name("Bill",     "Clinton"),
                             new Name("Scott",    "Pollack"),
                             new Name("Craig",    "Pollack")
                           };

    CompoundSort() {
        System.out.println("\nCompound Sort...\n");
        display("Initial Array");
        Arrays.sort(names, 0, names.length);
        display("Sorted Array");
    }

    public static void main(String[] args) {
        new CompoundSort();
    }

    private void display(String title) {
        System.out.println(title + "\n");
        for (int i = 0; i < names.length; i++)
            System.out.printf("%3d  %s\n", i, names[i]);
        System.out.println();
    }
        
}


//  A "Name" is a first name and a last name

class Name implements Comparable {

    private String first;
    private String last;

    Name() {
        first = last = "";
    }

    Name(String first, String last) {
        this.first = first;
        this.last  = last;
    }

    // This comparison method handles the comparison of
    // both primary and secondary fields
    public int compareTo(Object obj) {
        return (last.compareTo(((Name) obj).last) < 0) ? -1 :
               (last.compareTo(((Name) obj).last) > 0) ? +1 :
               (first.compareTo(((Name) obj).first));
    }

    public String toString() {
        return String.format("%s, %s", last, first);
    }

}

/* ===== Output from this program =====

Compound Sort...

Initial Array

  0  Pollack, Bary
  1  Bush, George
  2  Obama, Barack
  3  Bush, Jeb
  4  Clinton, Hillary
  5  McCain, John
  6  Pollack, Kimberly
  7  Bush, George W
  8  Clinton, Bill
  9  Pollack, Scott
 10  Pollack, Craig

Sorted Array

  0  Bush, George
  1  Bush, George W
  2  Bush, Jeb
  3  Clinton, Bill
  4  Clinton, Hillary
  5  McCain, John
  6  Obama, Barack
  7  Pollack, Bary
  8  Pollack, Craig
  9  Pollack, Kimberly
 10  Pollack, Scott

===== end of output ===== */
